searchNodes=[{"doc":"An interval represents the points between two endpoints. The interval can be empty. The empty interval is never contained in any other interval, and contains itself no points. It can be left and/or right unbounded, in which case it contains all points in the unbounded direction. A fully unbounded interval contains all other intervals, except the empty interval. Interval Notation Throughout the documentation and comments, you'll see a notation for writing about intervals. As this library is inspired by the functionality in PostgreSQL's range types, we align ourselves with it's notation choice and borrow it ( https://www.postgresql.org/docs/current/rangetypes.html ) with the exception that we write the normalised empty interval as (0,0) . This notation is also described in ISO 31-11. [ left - inclusive , right - inclusive ] ( left - exclusive , right - exclusive ) [ left - inclusive , right - exclusive ) ( left - exclusive , right - inclusive ] ( 0 , 0 ) An unbounded interval is written by omitting the bound type and point: , right - exclusive ) [ left - inclusive , When specifying bound types we sometimes leave the point out and just write the left and right bounds: [ ] ( ) ( ] [ ) ( ) [ ] Types of Interval This library ships with a few different types of intervals. The built-in intervals are intervals for Date DateTime Float Integer However, you can quite easily implement an interval using your own point types, by implementing the Interval.Point protocol. The Interval.Point protocols defines a few handfuls of functions you'll need to define on your struct to be able to use it as a point in the interval. An obvious usecase for this would be to implement an interval that works with the https://hexdocs.pm/decimal library. Discrete vs Continuous intervals Depending on the type of point used, an interval is either said to be discrete or continuous. A discrete interval represents a set of finite points (like integers or dates). A continuous can be said to represent the infinite number of points between two endpoints (like float and datetime). With discrete points, it is possible to define what the next and previous point is, and we normalise these intervals to the bound type [) . The only exception is the empty interval, which is still represented as the exclusive bounded zero point. For integers that would be (0,0) . The distinction between discrete and continuous intervals is important because the two behave slightly differently in some of the libraries functions. E.g. A discrete interval is adjacent to another discrete interval, if there is no points between the two interval. Contrast this to continuous intervals like real numbers where there is always an infinite number of real numbers between two distinct real numbers, and so continuous intervals are only said to be adjacent to each other if they include the same point, and one point is inclusive where the other is exclusive. Where relevant, the function documentation will mention the differences between discrete and continuous intervals. Create an Interval See new/1 . Normalization When creating an interval through new/1 , it will get normalized so that intervals that represents the same exact same points, are also represented in the same way in the struct. This allows you to compare two intervals for equality by using == (and using pattern matching). It is therefore not recommended to modify an Interval struct directly, but instead do so by using one of the functions that modify the interval. An interval is said to be empty if it spans zero points. We represent the empty interval as an exclusive interval in between two &quot;zero points&quot;. Any empty interval will be normalized to this (0,0) interval. see Interval.Point.zero/1 for details on what a zero point is.","ref":"Interval.html","title":"Interval","type":"module"},{"doc":"Is the interval a adjacent to b , to the left of b . a is adjacent to b left of b , if a and b do not overlap, and there are no points between a.right and b.left . a : [ -- - ) b : [ -- - ) r : true a : [ -- - ] b : [ -- - ] r : false ( overlaps ) a : ( -- - ) b : ( -- - ) r : false ( points exist between a . right and b . left ) Examples iex&gt; adjacent_left_of? ( new ( left : 1 , right : 2 ) , new ( left : 2 , right : 3 ) ) true iex&gt; adjacent_left_of? ( new ( left : 1 , right : 3 ) , new ( left : 2 , right : 4 ) ) false iex&gt; adjacent_left_of? ( new ( left : 3 , right : 4 ) , new ( left : 1 , right : 2 ) ) false iex&gt; adjacent_left_of? ( new ( right : 2 , bounds : &quot;[]&quot; ) , new ( left : 3 ) ) true","ref":"Interval.html#adjacent_left_of?/2","title":"Interval.adjacent_left_of?/2","type":"function"},{"doc":"Is the interval a adjacent to b , to the right of b . a is adjacent to b right of b , if a and b do not overlap, and there are no points between a.left and b.right . a : [ -- - ) b : [ -- - ) r : true a : [ -- - ) b : [ -- - ] r : false ( overlaps ) a : ( -- - ) b : ( -- - ) r : false ( points exist between a . left and b . right ) Examples iex&gt; adjacent_right_of? ( new ( left : 2 , right : 3 ) , new ( left : 1 , right : 2 ) ) true iex&gt; adjacent_right_of? ( new ( left : 1 , right : 3 ) , new ( left : 2 , right : 4 ) ) false iex&gt; adjacent_right_of? ( new ( left : 1 , right : 2 ) , new ( left : 3 , right : 4 ) ) false iex&gt; adjacent_right_of? ( new ( left : 3 ) , new ( right : 2 , bounds : &quot;]&quot; ) ) true","ref":"Interval.html#adjacent_right_of?/2","title":"Interval.adjacent_right_of?/2","type":"function"},{"doc":"Does a contain the point x ? Examples iex&gt; contains_point? ( new ( left : 1 , right : 2 ) , 0 ) false iex&gt; contains_point? ( new ( left : 1 , right : 2 ) , 1 ) true","ref":"Interval.html#contains_point?/2","title":"Interval.contains_point?/2","type":"function"},{"doc":"Does a contain b ? a contains b of all points in b is also in a . For an interval a to contain an interval b , all points in b must be contained in a : a : [ -- -- -- - ] b : [ -- - ] r : true a : [ -- - ] b : [ -- - ] r : true a : [ -- - ] b : ( -- - ) r : true a : ( -- - ) b : [ -- - ] r : false a : [ -- - ] b : [ -- -- -- - ] r : false This means that a.left is less than b.left (or unbounded), and a.right is greater than b.right (or unbounded) If a and b 's point match, then b is &quot;in&quot; a if a and b share bound types. E.g. if a.left and b.left matches, then a contains b if both a and b 's left is inclusive or exclusive. If either of b endpoints are unbounded, then a only contains b if the corresponding endpoint in a is also unbounded. Examples iex&gt; contains? ( new ( left : 1 , right : 2 ) , new ( left : 1 , right : 2 ) ) true iex&gt; contains? ( new ( left : 1 , right : 3 ) , new ( left : 2 , right : 3 ) ) true iex&gt; contains? ( new ( left : 2 , right : 3 ) , new ( left : 1 , right : 4 ) ) false iex&gt; contains? ( new ( left : 1 , right : 3 ) , new ( left : 1 , right : 2 ) ) true iex&gt; contains? ( new ( left : 1 , right : 2 , bounds : &quot;()&quot; ) , new ( left : 1 , right : 3 ) ) false iex&gt; contains? ( new ( right : 1 ) , new ( left : 0 , right : 1 ) ) true","ref":"Interval.html#contains?/2","title":"Interval.contains?/2","type":"function"},{"doc":"Is the interval empty? An empty interval is an interval that represents no points. Any interval containing no points is considered empty. An unbounded interval is never empty. For continuous points, the interval is empty when the left and right points are identical, and the point is not included in the interval. For discrete points, the interval is empty when the left and right point isn't inclusive, and there are no points between the left and right point. Examples iex&gt; empty? ( new ( left : 0 , right : 0 ) ) true iex&gt; empty? ( single ( 1.0 ) ) false iex&gt; empty? ( new ( left : 1 , right : 2 ) ) false","ref":"Interval.html#empty?/1","title":"Interval.empty?/1","type":"function"},{"doc":"","ref":"Interval.html#from_endpoints/2","title":"Interval.from_endpoints/2","type":"function"},{"doc":"Is the interval left-inclusive? The interval is left-inclusive if the left endpoint value is included in the interval. Note Discrete intervals (like integers and dates) are always normalized to be left-inclusive right-exclusive ( [) ) which this function reflects. iex&gt; inclusive_left? ( new ( left : 1.0 , right : 2.0 , bounds : &quot;[]&quot; ) ) true iex&gt; inclusive_left? ( new ( left : 1.0 , right : 2.0 , bounds : &quot;[)&quot; ) ) true iex&gt; inclusive_left? ( new ( left : 1.0 , right : 2.0 , bounds : &quot;()&quot; ) ) false","ref":"Interval.html#inclusive_left?/1","title":"Interval.inclusive_left?/1","type":"function"},{"doc":"Is the interval right-inclusive? The interval is right-inclusive if the right endpoint value is included in the interval. Note Discrete intervals (like integers and dates) are always normalized to be left-inclusive right-exclusive ( [) ) which this function reflects. iex&gt; inclusive_right? ( new ( left : 1.0 , right : 2.0 , bounds : &quot;[]&quot; ) ) true iex&gt; inclusive_right? ( new ( left : 1.0 , right : 2.0 , bounds : &quot;[)&quot; ) ) false iex&gt; inclusive_right? ( new ( left : 1.0 , right : 2.0 , bounds : &quot;()&quot; ) ) false","ref":"Interval.html#inclusive_right?/1","title":"Interval.inclusive_right?/1","type":"function"},{"doc":"Compute the intersection between a and b . The intersection contains all of the points that are both in a and b . If either a or b are empty, the returned interval will be empty. a : [ -- -- ] b : [ -- -- ] r : [ - ] a : ( -- -- ) b : ( -- -- ) r : ( - ) a : [ -- -- ) b : [ -- -- ) r : [ - ) Examples: Discrete: a : [ -- -- ) b : [ -- -- ) c : [ - ) iex&gt; intersection ( new ( left : 1 , right : 3 ) , new ( left : 2 , right : 4 ) ) new ( left : 2 , right : 3 ) Continuous: a : [ -- -- ) b : [ -- -- ) c : [ - ) iex&gt; intersection ( new ( left : 1.0 , right : 3.0 ) , new ( left : 2.0 , right : 4.0 ) ) new ( left : 2.0 , right : 3.0 ) a : ( -- -- ) b : ( -- -- ) c : ( - ) iex&gt; intersection ( ...&gt; new ( left : 1.0 , right : 3.0 , bounds : &quot;()&quot; ) , ...&gt; new ( left : 2.0 , right : 4.0 , bounds : &quot;()&quot; ) ...&gt; ) new ( left : 2.0 , right : 3.0 , bounds : &quot;()&quot; ) a : [ -- -- - ) b : [ -- -- -- - c : [ -- - ) iex&gt; intersection ( new ( left : 1.0 , right : 3.0 ) , new ( left : 2.0 ) ) new ( left : 2.0 , right : 3.0 )","ref":"Interval.html#intersection/2","title":"Interval.intersection/2","type":"function"},{"doc":"Create a new unbounded interval. This is the exactly the same as new/1 with an empty list of options.","ref":"Interval.html#new/0","title":"Interval.new/0","type":"function"},{"doc":"Create a new interval. Options left The left (or lower) endpoint of the interval right The right (or upper) endpoint of the interval bounds The bound mode to use. Defaults to &quot;[)&quot; A nil ( left or right ) endpoint is considered unbounded. The endpoint will also be considered unbounded if the bounds is explicitly set as unbounded. Bounds The bounds options contains the left and right bound mode to use. The bound can be inclusive, exclusive or unbounded. The following valid bound values are supported: &quot;[)&quot; left-inclusive, right-exclusive (default) &quot;(]&quot; left-exclusive, right-inclusive &quot;[]&quot; left-inclusive, right-inclusive &quot;()&quot; left-exclusive, right-exclusive &quot;)&quot; left-unbounded, right-exclusive &quot;]&quot; left-unbounded, right-inclusive &quot;(&quot; left-exclusive, right-unbounded &quot;[&quot; left-inclusive, right-unbounded Examples iex&gt; new ( [ ] ) iex&gt; new ( left : 1 ) iex&gt; new ( left : 1 , right : 1 , bounds : &quot;[]&quot; ) iex&gt; new ( left : 10 , right : 20 , bounds : &quot;()&quot; )","ref":"Interval.html#new/1","title":"Interval.new/1","type":"function"},{"doc":"Normalize an Interval struct","ref":"Interval.html#normalize/1","title":"Interval.normalize/1","type":"function"},{"doc":"Does a overlap with b ? a overlaps with b if any point in a is also in b . a : [ -- - ) b : [ -- - ) r : true a : [ -- - ) b : [ -- - ) r : false a : [ -- - ] b : [ -- - ] r : true a : ( -- - ) b : ( -- - ) r : false a : [ -- - ) b : [ -- - ) r : false Examples [ -- a -- ) [ -- b -- ) iex&gt; overlaps? ( new ( left : 1 , right : 3 ) , new ( left : 2 , right : 4 ) ) true [ -- a -- ) [ -- b -- ) iex&gt; overlaps? ( new ( left : 1 , right : 3 ) , new ( left : 3 , right : 5 ) ) false [ -- a -- ] [ -- b -- ] iex&gt; overlaps? ( new ( left : 1 , right : 3 ) , new ( left : 2 , right : 4 ) ) true ( -- a -- ) ( -- b -- ) iex&gt; overlaps? ( new ( left : 1 , right : 3 ) , new ( left : 3 , right : 5 ) ) false [ -- a -- ) [ -- b -- ) iex&gt; overlaps? ( new ( left : 1 , right : 2 ) , new ( left : 3 , right : 4 ) ) false","ref":"Interval.html#overlaps?/2","title":"Interval.overlaps?/2","type":"function"},{"doc":"Partition an interval a into 3 intervals using x : The interval with all points from a &lt; x The interval with just x The interval with all points from a &gt; x If x is not in a this function returns an empty list. Examples iex&gt; partition ( new ( left : 1 , right : 5 , bounds : &quot;[]&quot; ) , 3 ) [ new ( left : 1 , right : 3 , bounds : &quot;[)&quot; ) , new ( left : 3 , right : 3 , bounds : &quot;[]&quot; ) , new ( left : 3 , right : 5 , bounds : &quot;(]&quot; ) ] iex&gt; partition ( new ( left : 1 , right : 5 ) , - 10 ) [ ]","ref":"Interval.html#partition/2","title":"Interval.partition/2","type":"function"},{"doc":"Create a new Interval containing a single point.","ref":"Interval.html#single/1","title":"Interval.single/1","type":"function"},{"doc":"Return the &quot;size&quot; of the interval. The returned value depends on the Point implementation used. If the interval is unbounded, this function returns nil . Note The size is implemented as right - left , ignoring inclusive/exclusive bounds. This works for discrete intervals because they are always normalized to [) . The implementation is the same for continuous intervals, but here we completely ignore the bounds, so the size of (1.0, 3.0) is exactly the same as the size of [1.0, 3.0] . A second argument unit can be given to this function, which in turn is handed to the call to Interval.Point.subtract/3 , to return the difference between the two points in the desired unit. The default value for unit is Point implementation specific. These are the default returned sizes for the built-in implementations: Date - days (integer) DateTime - seconds (integer) Integer - integer Float - float For Discrete Intervals For discrete point types, the size represents the number of elements the interval contains (or nil , when empty). I.e. for Date the size is the number of Date structs the interval can be said to &quot;contain&quot; (aka. number of days) Examples iex&gt; size ( new ( left : 1 , right : 1 , bounds : &quot;[]&quot; ) ) 1 iex&gt; size ( new ( left : 1 , right : 3 , bounds : &quot;[)&quot; ) ) 2 # Note that this interval will be normalized to an empty (0,0) interval # but the math is still the same: `right - left` iex&gt; size ( new ( left : 1 , right : 2 , bounds : &quot;()&quot; ) ) 0 For Continuous Intervals For continuous intervals, the size is reported as the difference between the left and right points. Examples # The size of the interval `[1.0, 5.0)` is also 4: iex&gt; size ( new ( left : 1.0 , right : 5.0 , bounds : &quot;[)&quot; ) ) 4.0 # And likewise, so is the size of `[1.0, 5.0]` (note the bound change) iex&gt; size ( new ( left : 1.0 , right : 5.0 , bounds : &quot;[]&quot; ) ) 4.0 # Exactly one point contained in this continuous interval, # so technically not empty, but it also has zero size. iex&gt; size ( new ( left : 1.0 , right : 1.0 , bounds : &quot;[]&quot; ) ) 0.0 # Empty continuous interval iex&gt; size ( new ( left : 1.0 , right : 1.0 , bounds : &quot;()&quot; ) ) 0.0","ref":"Interval.html#size/2","title":"Interval.size/2","type":"function"},{"doc":"Is a strictly left of b . a is strictly left of b if no point in a is in b , and all points in a is left (&lt;) of all points in b . Examples a : [ -- - ) b : [ -- - ) r : true a : [ -- - ) b : [ -- - ) r : true a : [ -- - ) b : [ -- - ) r : false ( overlaps ) iex&gt; strictly_left_of? ( new ( left : 1 , right : 2 ) , new ( left : 3 , right : 4 ) ) true iex&gt; strictly_left_of? ( new ( left : 1 , right : 3 ) , new ( left : 2 , right : 4 ) ) false iex&gt; strictly_left_of? ( new ( left : 3 , right : 4 ) , new ( left : 1 , right : 2 ) ) false","ref":"Interval.html#strictly_left_of?/2","title":"Interval.strictly_left_of?/2","type":"function"},{"doc":"Is a strictly right of b . a is strictly right of b if no point in a is in b , and all points in a is right (&gt;) of all points in b . Examples a : [ -- - ) b : [ -- - ) r : true a : [ -- - ) b : [ -- - ) r : true a : [ -- - ) b : [ -- - ) r : false ( overlaps ) iex&gt; strictly_right_of? ( new ( left : 1 , right : 2 ) , new ( left : 3 , right : 4 ) ) false iex&gt; strictly_right_of? ( new ( left : 1 , right : 3 ) , new ( left : 2 , right : 4 ) ) false iex&gt; strictly_right_of? ( new ( left : 3 , right : 4 ) , new ( left : 1 , right : 2 ) ) true","ref":"Interval.html#strictly_right_of?/2","title":"Interval.strictly_right_of?/2","type":"function"},{"doc":"Check if the interval is left-unbounded. The interval is left-unbounded if all points left of the right bound is included in this interval. Examples iex&gt; unbounded_left? ( new ( ) ) true iex&gt; unbounded_left? ( new ( right : 2 ) ) true iex&gt; unbounded_left? ( new ( left : 1 , right : 2 ) ) false","ref":"Interval.html#unbounded_left?/1","title":"Interval.unbounded_left?/1","type":"function"},{"doc":"Check if the interval is right-unbounded. The interval is right-unbounded if all points right of the left bound is included in this interval. Examples iex&gt; unbounded_right? ( new ( right : 1 ) ) false iex&gt; unbounded_right? ( new ( ) ) true iex&gt; unbounded_right? ( new ( left : 1 ) ) true","ref":"Interval.html#unbounded_right?/1","title":"Interval.unbounded_right?/1","type":"function"},{"doc":"Computes the union of a and b . The union contains all of the points that are either in a or b . If either a or b are empty, the returned interval will be empty. a : [ -- - ) b : [ -- - ) r : [ -- -- - ) Examples [ -- A -- ) [ -- B -- ) [ -- -- C -- -- ) iex&gt; union ( new ( left : 1 , right : 3 ) , new ( left : 2 , right : 4 ) ) new ( left : 1 , right : 4 ) [ - A - ) [ - B - ) [ -- - C -- - ) iex&gt; union ( new ( left : 1 , right : 2 ) , new ( left : 2 , right : 3 ) ) new ( left : 1 , right : 3 ) iex&gt; union ( new ( left : 1 , right : 2 ) , new ( left : 3 , right : 4 ) ) new ( left : 0 , right : 0 )","ref":"Interval.html#union/2","title":"Interval.union/2","type":"function"},{"doc":"","ref":"Interval.html#t:bound/0","title":"Interval.bound/0","type":"type"},{"doc":"Shorthand for t:t(any())","ref":"Interval.html#t:t/0","title":"Interval.t/0","type":"type"},{"doc":"The Interval struct, representing all points between two endpoints. The struct has two fields: left and right , representing the left (lower) and right (upper) points in the interval.","ref":"Interval.html#t:t/1","title":"Interval.t/1","type":"type"},{"doc":"The Interval.Point protocol defines a set of functions the Interval module needs to use a value as a point in an interval. Implementing this protocol for a type allows you to use that type as a point in the Interval type. Point Types Interval accepts two kinds of point types: Discrete Continuous Discrete A discrete point type is one where the number of points in a bounded interval is finite and knowable. Every discrete point has a concept of the next/1 and previous/1 point (in contrast to something like a real number where there exists an infinite number of points between two other points) Continuous The continuous point type is for points where there exists (at least conceptually) an infinite number of points between two other points. Examples of this are floats, points in time, etc. These points have no useful notion of the &quot;next&quot; and &quot;previous&quot; point, and implements these functions as raising an error. Default Implementations This library ships with implementations for Date (discrete) Integer (discrete) DateTime (continuous) Float (continuous) If you wish to implement the Interval.Point protocol for one of these types yourself, you can disable the built-in implementation by setting the module to false under the :interval OTP application: import Config config :interval , Date , false","ref":"Interval.Point.html","title":"Interval.Point","type":"protocol"},{"doc":"Add value_to_add to a . value_to_add is in the unit given as third argument. The supported units are implementation specific, however they should mirror the available units of subtract/3 , such that iex&gt; add ( b , subtract ( a , b ) ) == a and the default uni of subtract/3 must also be the default unit of add/3","ref":"Interval.Point.html#add/3","title":"Interval.Point.add/3","type":"function"},{"doc":"Compare two interval points (of the same time) and returns if a is less than equal greater than b","ref":"Interval.Point.html#compare/2","title":"Interval.Point.compare/2","type":"function"},{"doc":"Return the largest (right-most) of the two points.","ref":"Interval.Point.html#max/2","title":"Interval.Point.max/2","type":"function"},{"doc":"Return the smallest (left-most) of the two points.","ref":"Interval.Point.html#min/2","title":"Interval.Point.min/2","type":"function"},{"doc":"Given a point A, return the next value after A. If the point type is continuous then this function should return a","ref":"Interval.Point.html#next/1","title":"Interval.Point.next/1","type":"function"},{"doc":"Given a point A, return the previous value after A. If the point type is continuous then this function should return a","ref":"Interval.Point.html#previous/1","title":"Interval.Point.previous/1","type":"function"},{"doc":"subtract b from a , returning the value in a unit that is relevant for the given point type. An optional argument unit can be specified if the point type has multiple units of relevance. The supported units are implementation specific.","ref":"Interval.Point.html#subtract/3","title":"Interval.Point.subtract/3","type":"function"},{"doc":"Returns if the Point lies on a discrete (like integer) or a continuous line (like floats).","ref":"Interval.Point.html#type/1","title":"Interval.Point.type/1","type":"function"},{"doc":"Returns the &quot;zero&quot; value for this point type. This is used provide the point value used for empty intervals.","ref":"Interval.Point.html#zero/1","title":"Interval.Point.zero/1","type":"function"},{"doc":"","ref":"Interval.Point.html#t:t/0","title":"Interval.Point.t/0","type":"type"},{"doc":"Datatype and operations for both discrete and continuous intervals, Inspired by PostgreSQL's range types . Find the documentation at https://hexdocs.pm/interval/","ref":"readme.html","title":"Interval","type":"extras"},{"doc":"The package can be installed by adding interval to your list of dependencies in mix.exs : def deps do [ { :interval , &quot;~&gt; 0.1.3&quot; } ] end","ref":"readme.html#installation","title":"Interval - Installation","type":"extras"},{"doc":"Integer intervals a = Interval . new ( left : 1 , right : 4 , bounds : &quot;[]&quot; ) b = Interval . new ( left : 2 , right : 5 , bounds : &quot;[]&quot; ) assert Interval . contains? ( a , b ) assert Interval . overlaps? ( a , b ) c = Interval . intersection ( a , b ) # [2, 4] d = Interval . union ( a , b ) # [1, 5] DateTime intervals # default bound is &quot;[)&quot; y2022 = Interval . new ( left : ~U[2022-01-01 00:00:00Z] , right : ~U[2023-01-01 00:00:00Z] ) x = Interval . new ( left : ~U[2018-07-01 00:00:00Z] , right : ~U[2022-03-01 00:00:00Z] ) Interval . intersection ( y2022 , x ) # %Interval{ # left: {:inclusive, ~U[2022-01-01 00:00:00Z]}, # right: {:exclusive, ~U[2022-03-01 00:00:00Z]} # }","ref":"readme.html#examples","title":"Interval - Examples","type":"extras"},{"doc":"","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Adding Interval.contains_point?/2 Adding Interval.partition/2","ref":"changelog.html#head-v0-1-4","title":"Changelog - HEAD (v0.1.4)","type":"extras"},{"doc":"Fixed a bug in Interval.intersection/2 and Interval.union/2 that causes incorrect bounds in some cases. The internal Endpoint struct has been replaced by a simple 2-tuple. Empty intervals are now represented by two identical exclusive points. Added Interval.size/2 . Added parameterized typespec Interval.t/1","ref":"changelog.html#v0-1-3","title":"Changelog - v0.1.3","type":"extras"},{"doc":"Fixed a correctness bug in intersection, where intersections between intervals containing unbounded endpoints would be incorrectly computed.","ref":"changelog.html#v0-1-2","title":"Changelog - v0.1.2","type":"extras"}]